.. _api_transport:

.. py:module:: pynetdicom.transport

Transport Service (:mod:`pynetdicom.transport`)
===============================================

.. currentmodule:: pynetdicom.transport

The Transport Service handles creation of the servers and clients used to
communication with peer AEs.

.. currentmodule:: pynetdicom.transport

.. autosummary::
   :toctree: generated/

   AssociationSocket
   AssociationServer
   AddressInformation
   RequestHandler
   ThreadedAssociationServer
   T_CONNECT
